==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQtマウステーマの設定</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>使いたいカーソルテーマを選択 (プレビューをテストカーソルに合わせます). &lt;b&gt;LXQtセッションはこの変更後に再起動が必要です&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>新しいテーマのインストール...(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>テーマの削除(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme エラー</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>アクティブなテーマは削除できません!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>フォーム</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>カーソルテーマを見つけられませんでした。代わりに、デフォルトのX11カーソルテーマが使われます。LXQtは以下のディレクトリーを検索しました:</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>表示</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>説明</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQtマウステーマの設定</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>使いたいカーソルテーマを選択 (プレビューをテストカーソルに合わせます). &lt;b&gt;LXQtセッションはこの変更後に再起動が必要です&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>新しいテーマのインストール(&amp;I)...</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>テーマの削除(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="212"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme エラー</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="213"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>アクティブなテーマは削除できません!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>フォーム</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>カーソルテーマを見つけられませんでした。代わりに、デフォルトのX11カーソルテーマが使われます。LXQtは以下のディレクトリーを検索しました:</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>表示...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>説明</translation>
    </message>
</context>
</TS>
